//*****************************************************************************
//
// graphics.c - Simple Graphics Display Example
//
// Copyright (c) 2006-2008 Luminary Micro, Inc.  All rights reserved.
// Software License Agreement
// 
// Luminary Micro, Inc. (LMI) is supplying this software for use solely and
// exclusively on LMI's microcontroller products.
// 
// The software is owned by LMI and/or its suppliers, and is protected under
// applicable copyright laws.  All rights are reserved.  You may not combine
// this software with "viral" open-source software in order to form a larger
// program.  Any use in violation of the foregoing restrictions may subject
// the user to criminal sanctions under applicable laws, as well as to civil
// liability for the breach of the terms and conditions of this license.
// 
// THIS SOFTWARE IS PROVIDED "AS IS".  NO WARRANTIES, WHETHER EXPRESS, IMPLIED
// OR STATUTORY, INCLUDING, BUT NOT LIMITED TO, IMPLIED WARRANTIES OF
// MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE APPLY TO THIS SOFTWARE.
// LMI SHALL NOT, IN ANY CIRCUMSTANCES, BE LIABLE FOR SPECIAL, INCIDENTAL, OR
// CONSEQUENTIAL DAMAGES, FOR ANY REASON WHATSOEVER.
// 
// This is part of revision 3740 of the EK-LM3S2965 Firmware Package.
//
//*****************************************************************************

#include "../../../hw_types.h"
#include "../../../driverlib/debug.h"
#include "../../../driverlib/sysctl.h"
#include "../osram128x64x4.h"

//*****************************************************************************
//
//! \addtogroup example_list
//! <h1>Graphics Example (graphics)</h1>
//!
//! A simple application that displays scrolling text on the top line of the
//! OLED display, along with a 4-bit gray scale image.
//
//*****************************************************************************

//*****************************************************************************
//
// Simple 4-bit gray scale image for test.  This image was extracted from a
// 4-bit gray scale Bit Map (BMP) format file.
//
//*****************************************************************************
static unsigned char g_pucLogo[55][64] =
{
    {
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff
    },
    {
        0xdb, 0xbb, 0xba, 0xdf, 0xff, 0xda, 0x9a, 0xbd,
        0xff, 0xff, 0xbb, 0xfd, 0xad, 0xfb, 0xbf, 0xff,
        0xda, 0xcf, 0xff, 0xca, 0xdf, 0xfb, 0xac, 0xff,
        0xda, 0xcf, 0xff, 0xba, 0xef, 0xfb, 0xbe, 0xff,
        0xba, 0xef, 0xff, 0xfd, 0xac, 0xff, 0xff, 0xfe,
        0xcf, 0xfa, 0xef, 0xcc, 0xff, 0xcd, 0xff, 0xfd,
        0x99, 0x9c, 0xff, 0xfe, 0xcf, 0xff, 0xcc, 0xff,
        0xfd, 0x99, 0x9c, 0xff, 0xff, 0xff, 0xff, 0xff
    },
    {
        0xb8, 0x99, 0x99, 0xcf, 0xfc, 0x88, 0xaa, 0x88,
        0xdf, 0xfe, 0x89, 0xf9, 0x8a, 0xf8, 0x8e, 0xff,
        0xc8, 0xaf, 0xff, 0xa8, 0xcf, 0xc8, 0x8a, 0xff,
        0xd8, 0x9a, 0xaa, 0x89, 0xef, 0xf9, 0x8d, 0xff,
        0x98, 0xdf, 0xff, 0xfb, 0x8a, 0xff, 0xff, 0xfc,
        0x9f, 0xc7, 0xaf, 0xab, 0xff, 0xab, 0xff, 0xd8,
        0xce, 0xd9, 0xbf, 0xfc, 0x9f, 0xff, 0xab, 0xff,
        0xc8, 0xde, 0xd9, 0xbf, 0xff, 0xff, 0xff, 0xff
    },
    {
        0xb8, 0xbf, 0xff, 0xff, 0xfa, 0x8b, 0xff, 0xa8,
        0xcf, 0xfe, 0x99, 0xd9, 0x99, 0xe9, 0x9e, 0xff,
        0xc8, 0xaf, 0xff, 0xa8, 0xdd, 0x88, 0x8a, 0xff,
        0xfa, 0x89, 0x99, 0x8b, 0xff, 0xf9, 0x8a, 0xba,
        0x89, 0xef, 0xff, 0xfb, 0x8a, 0xff, 0xff, 0xfc,
        0xaf, 0x9d, 0x9e, 0xbb, 0xff, 0xab, 0xff, 0x9c,
        0xff, 0xfe, 0xaf, 0xfd, 0xaf, 0xff, 0x9d, 0xff,
        0x8d, 0xff, 0xfe, 0x8f, 0xff, 0xff, 0xff, 0xff
    },
    {
        0xb8, 0xbf, 0xff, 0xff, 0xfa, 0x8c, 0xff, 0xa8,
        0xcf, 0xfe, 0x99, 0xb8, 0xc8, 0xb9, 0x9e, 0xff,
        0xc8, 0xaf, 0xff, 0xa8, 0xc9, 0x9b, 0x8a, 0xff,
        0xfd, 0x8a, 0xe9, 0x9e, 0xff, 0xf9, 0x89, 0x99,
        0x8a, 0xff, 0xff, 0xd8, 0x88, 0xcf, 0xff, 0xfc,
        0xac, 0xaf, 0xba, 0xbb, 0xff, 0xab, 0xff, 0x9d,
        0xff, 0xff, 0xff, 0xfd, 0x79, 0x98, 0x8f, 0xff,
        0x9f, 0xff, 0xff, 0x8e, 0xff, 0xef, 0xee, 0xee
    },
    {
        0xb8, 0xbf, 0xff, 0xff, 0xfa, 0x8c, 0xff, 0xa8,
        0xcf, 0xfe, 0x99, 0x9a, 0xf9, 0x99, 0x9f, 0xff,
        0xc8, 0xaf, 0xff, 0xa8, 0x98, 0xcd, 0x8a, 0xff,
        0xff, 0x99, 0xb8, 0xaf, 0xff, 0xf9, 0x8d, 0xfe,
        0x98, 0xdf, 0xff, 0x98, 0xa9, 0x9e, 0xff, 0xfd,
        0xa8, 0xef, 0xf9, 0x9b, 0xff, 0xab, 0xff, 0x9c,
        0xff, 0xff, 0xcf, 0xfd, 0xaf, 0xff, 0x9b, 0xff,
        0x8e, 0xff, 0xff, 0x8f, 0xff, 0x9e, 0xaa, 0x9a
    },
    {
        0xb8, 0xbf, 0xff, 0xff, 0xfa, 0x8c, 0xff, 0xa8,
        0xbf, 0xfe, 0x88, 0x8c, 0xfb, 0x88, 0x9e, 0xff,
        0xc8, 0xaf, 0xff, 0xa8, 0x8b, 0xfc, 0x8a, 0xff,
        0xff, 0xc8, 0x88, 0xdf, 0xff, 0xf9, 0x89, 0xa9,
        0x88, 0xdf, 0xfb, 0x89, 0xfa, 0x8a, 0xff, 0xfd,
        0x6a, 0xff, 0xfc, 0x6b, 0xff, 0xab, 0xff, 0xd8,
        0xdf, 0xfa, 0xaf, 0xfd, 0x9e, 0xee, 0x9b, 0xff,
        0xb8, 0xef, 0xe9, 0xbf, 0xff, 0x9e, 0x99, 0xb8
    },
    {
        0xc9, 0xcf, 0xff, 0xff, 0xfb, 0x9d, 0xff, 0xb9,
        0xcf, 0xfe, 0xaa, 0xae, 0xfd, 0xaa, 0xaf, 0xff,
        0xd9, 0xbf, 0xff, 0xba, 0xaf, 0xfd, 0x9b, 0xff,
        0xff, 0xfa, 0xab, 0xff, 0xff, 0xfa, 0xaa, 0xaa,
        0xac, 0xff, 0xea, 0xad, 0xfe, 0xaa, 0xef, 0xfd,
        0x8e, 0xff, 0xff, 0x9c, 0xff, 0xbc, 0xff, 0xfc,
        0x99, 0x9a, 0xff, 0xfe, 0x89, 0x99, 0xaf, 0xff,
        0xfb, 0x99, 0x9a, 0xff, 0xfc, 0x9b, 0xac, 0xfa
    },
    {
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xfe, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xfe, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff
    },
    {
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xfe, 0xed, 0xdd, 0xdd,
        0xdd, 0xdd, 0xdd, 0xdd, 0xdd, 0xdd, 0xdd, 0xdd,
        0xef, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff
    },
    {
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xc9, 0x87, 0x66, 0x66, 0x66,
        0x66, 0x66, 0x66, 0x66, 0x66, 0x66, 0x66, 0x65,
        0xbf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff
    },
    {
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xfd, 0xa7, 0x65, 0x66, 0x66, 0x66, 0x66,
        0x66, 0x66, 0x66, 0x66, 0x66, 0x66, 0x66, 0x65,
        0xaf, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff
    },
    {
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xfe, 0x96, 0x56, 0x66, 0x66, 0x66, 0x66, 0x66,
        0x66, 0x66, 0x66, 0x66, 0x66, 0x66, 0x66, 0x66,
        0xae, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff
    },
    {
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xc7, 0x56, 0x66, 0x66, 0x66, 0x66, 0x66, 0x66,
        0x66, 0x66, 0x66, 0x66, 0x66, 0x66, 0x66, 0x66,
        0xae, 0xef, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff
    },
    {
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xfa,
        0x66, 0x66, 0x66, 0x66, 0x66, 0x66, 0x66, 0x66,
        0x66, 0x66, 0x66, 0x66, 0x66, 0x66, 0x66, 0x66,
        0xae, 0xef, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff
    },
    {
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0x95,
        0x66, 0x66, 0x66, 0x66, 0x89, 0xaa, 0xaa, 0xbb,
        0xab, 0xba, 0xab, 0xba, 0xab, 0xa6, 0x66, 0x66,
        0xae, 0xef, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff
    },
    {
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xf9, 0x56,
        0x66, 0x66, 0x67, 0x9b, 0xcc, 0xdd, 0xdd, 0xdd,
        0xdd, 0xdd, 0xdd, 0xdd, 0xdd, 0xc6, 0x66, 0x66,
        0xae, 0xef, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff
    },
    {
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xa5, 0x66,
        0x66, 0x66, 0x9c, 0xcc, 0xdd, 0xdd, 0xdd, 0xdd,
        0xdd, 0xdd, 0xdd, 0xdd, 0xde, 0xd7, 0x66, 0x66,
        0xae, 0xef, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff
    },
    {
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xfc, 0x66, 0x66,
        0x66, 0x6b, 0xcc, 0xdd, 0xde, 0xee, 0xee, 0xee,
        0xfe, 0xee, 0xee, 0xee, 0xee, 0xe7, 0x66, 0x66,
        0xae, 0xef, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff
    },
    {
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xe7, 0x66, 0x66,
        0x67, 0xbc, 0xcd, 0xde, 0xef, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xe7, 0x66, 0x66,
        0xad, 0xef, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff
    },
    {
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xa5, 0x66, 0x66,
        0x6c, 0xcd, 0xde, 0xef, 0xff, 0xff, 0xff, 0xd7,
        0x88, 0x88, 0xef, 0xff, 0xff, 0xe7, 0x66, 0x66,
        0xad, 0xef, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff
    },
    {
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xfe, 0x66, 0x66, 0x66,
        0xac, 0xdd, 0xef, 0xff, 0xff, 0xff, 0xff, 0xc5,
        0x66, 0x56, 0xdf, 0xff, 0xff, 0xe7, 0x66, 0x66,
        0xae, 0xef, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff
    },
    {
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xfa, 0x56, 0x66, 0x69,
        0xcd, 0xde, 0xef, 0xf8, 0xdf, 0xff, 0xff, 0xc6,
        0x66, 0x66, 0xce, 0xff, 0xff, 0xe7, 0x66, 0x66,
        0xad, 0xef, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff
    },
    {
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xf7, 0x66, 0x66, 0x6c,
        0xdd, 0xef, 0xff, 0x86, 0xdf, 0xff, 0xff, 0xc6,
        0x66, 0x66, 0xce, 0xef, 0xff, 0xe7, 0x66, 0x66,
        0xae, 0xef, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff
    },
    {
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xd6, 0x66, 0x66, 0x9d,
        0xde, 0xef, 0xf9, 0x56, 0xdf, 0xff, 0xff, 0xc6,
        0x66, 0x66, 0xce, 0xef, 0xff, 0xe7, 0x66, 0x66,
        0xad, 0xef, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff
    },
    {
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xa5, 0x66, 0x66, 0xbd,
        0xde, 0xff, 0xd6, 0x66, 0xce, 0xff, 0xff, 0xc6,
        0x66, 0x66, 0xce, 0xef, 0xff, 0xe7, 0x66, 0x66,
        0xae, 0xef, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff
    },
    {
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0x85, 0x66, 0x67, 0xcd,
        0xef, 0xff, 0x86, 0x66, 0xce, 0xef, 0xff, 0xc6,
        0x66, 0x66, 0xbe, 0xef, 0xff, 0xe7, 0x66, 0x66,
        0xae, 0xef, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff
    },
    {
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0x76, 0x66, 0x69, 0xdd,
        0xef, 0xfc, 0x66, 0x66, 0xce, 0xef, 0xff, 0xc6,
        0x66, 0x66, 0xbe, 0xef, 0xff, 0xe7, 0x66, 0x66,
        0xad, 0xef, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff
    },
    {
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xfe, 0x66, 0x66, 0x6a, 0xde,
        0xef, 0xf9, 0x56, 0x66, 0xce, 0xef, 0xff, 0xc6,
        0x66, 0x66, 0xbe, 0xef, 0xff, 0xe7, 0x66, 0x66,
        0xae, 0xef, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff
    },
    {
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xfe, 0x66, 0x66, 0x6a, 0xde,
        0xff, 0xf7, 0x66, 0x66, 0xbe, 0xef, 0xff, 0xc6,
        0x66, 0x66, 0xbe, 0xef, 0xff, 0xe7, 0x66, 0x66,
        0xad, 0xef, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff
    },
    {
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xfd, 0x66, 0x66, 0x6b, 0xde,
        0xff, 0xd6, 0x66, 0x66, 0xbe, 0xef, 0xff, 0xc6,
        0x66, 0x66, 0xbe, 0xef, 0xff, 0xe6, 0x66, 0x66,
        0xad, 0xef, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff
    },
    {
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xfd, 0x66, 0x66, 0x6b, 0xde,
        0xff, 0xd6, 0x66, 0x66, 0xbe, 0xef, 0xff, 0xc6,
        0x66, 0x66, 0xbe, 0xef, 0xff, 0xe6, 0x66, 0x66,
        0xae, 0xef, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff
    },
    {
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xfe, 0x66, 0x66, 0x6b, 0xde,
        0xff, 0xd6, 0x66, 0x66, 0xbe, 0xef, 0xff, 0xc6,
        0x66, 0x66, 0xbe, 0xef, 0xff, 0xd6, 0x66, 0x66,
        0xad, 0xef, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff
    },
    {
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xfe, 0x66, 0x66, 0x6b, 0xde,
        0xff, 0xd6, 0x66, 0x66, 0xbe, 0xef, 0xff, 0xc6,
        0x66, 0x66, 0xbe, 0xef, 0xff, 0xb5, 0x66, 0x66,
        0xbd, 0xef, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff
    },
    {
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xfd, 0x66, 0x66, 0x6b, 0xee,
        0xff, 0xd6, 0x66, 0x66, 0xbe, 0xef, 0xff, 0xc6,
        0x66, 0x66, 0xbe, 0xef, 0xff, 0x95, 0x66, 0x67,
        0xcd, 0xef, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff
    },
    {
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xfd, 0x66, 0x66, 0x6b, 0xde,
        0xff, 0xd6, 0x66, 0x66, 0xbe, 0xef, 0xff, 0xc6,
        0x66, 0x66, 0xbe, 0xef, 0xfe, 0x76, 0x66, 0x68,
        0xdd, 0xef, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff
    },
    {
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xfe, 0x66, 0x66, 0x6b, 0xde,
        0xff, 0xd6, 0x66, 0x66, 0xbe, 0xef, 0xff, 0xc6,
        0x66, 0x66, 0xbe, 0xef, 0xfb, 0x56, 0x66, 0x6a,
        0xde, 0xef, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff
    },
    {
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xfd, 0x66, 0x66, 0x6b, 0xee,
        0xff, 0xc6, 0x66, 0x66, 0xbe, 0xef, 0xff, 0xc6,
        0x66, 0x66, 0xbe, 0xef, 0xe7, 0x66, 0x66, 0x6c,
        0xde, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff
    },
    {
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xfe, 0x66, 0x66, 0x6b, 0xee,
        0xff, 0xd6, 0x66, 0x66, 0xbe, 0xef, 0xff, 0xc6,
        0x66, 0x66, 0xbe, 0xef, 0x95, 0x66, 0x66, 0x8d,
        0xde, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff
    },
    {
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xfe, 0x66, 0x66, 0x6b, 0xde,
        0xff, 0xd6, 0x66, 0x66, 0xbe, 0xef, 0xff, 0xc6,
        0x66, 0x66, 0xbe, 0xfb, 0x66, 0x66, 0x66, 0xbd,
        0xde, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff
    },
    {
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xfe, 0x66, 0x66, 0x6b, 0xde,
        0xff, 0xd6, 0x66, 0x66, 0xbe, 0xef, 0xff, 0xc6,
        0x66, 0x66, 0xbe, 0xc6, 0x66, 0x66, 0x69, 0xdd,
        0xef, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff
    },
    {
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xfe, 0x66, 0x66, 0x6b, 0xde,
        0xff, 0xd6, 0x66, 0x66, 0xbe, 0xef, 0xff, 0xc6,
        0x66, 0x66, 0xcb, 0x66, 0x66, 0x66, 0x7c, 0xdd,
        0xef, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff
    },
    {
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xfe, 0x66, 0x66, 0x6b, 0xde,
        0xff, 0xd6, 0x66, 0x66, 0xbe, 0xef, 0xff, 0xc6,
        0x66, 0x66, 0x86, 0x66, 0x66, 0x66, 0xbd, 0xde,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff
    },
    {
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xfe, 0x66, 0x66, 0x6b, 0xee,
        0xff, 0xd6, 0x66, 0x66, 0xbe, 0xef, 0xff, 0xc6,
        0x66, 0x66, 0x66, 0x66, 0x66, 0x6a, 0xdd, 0xde,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff
    },
    {
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xfd, 0x66, 0x66, 0x6b, 0xde,
        0xff, 0xd6, 0x66, 0x66, 0xce, 0xff, 0xff, 0xb6,
        0x66, 0x66, 0x66, 0x66, 0x66, 0x9c, 0xdd, 0xef,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff
    },
    {
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xfd, 0x66, 0x66, 0x6b, 0xde,
        0xff, 0xd6, 0x66, 0x66, 0x78, 0x88, 0x87, 0x66,
        0x66, 0x66, 0x66, 0x66, 0x6a, 0xcc, 0xde, 0xef,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff
    },
    {
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xfd, 0x66, 0x66, 0x6b, 0xde,
        0xff, 0xd6, 0x66, 0x66, 0x66, 0x66, 0x66, 0x66,
        0x66, 0x66, 0x66, 0x67, 0xac, 0xcd, 0xee, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff
    },
    {
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xfd, 0x66, 0x66, 0x6b, 0xee,
        0xff, 0xd6, 0x66, 0x66, 0x66, 0x66, 0x66, 0x66,
        0x66, 0x66, 0x56, 0x8c, 0xcd, 0xde, 0xef, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff
    },
    {
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xfd, 0x66, 0x66, 0x6b, 0xee,
        0xff, 0xd6, 0x66, 0x66, 0x66, 0x66, 0x66, 0x66,
        0x66, 0x66, 0x8b, 0xcc, 0xdd, 0xee, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff
    },
    {
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xfd, 0x65, 0x66, 0x5b, 0xde,
        0xff, 0xc5, 0x56, 0x66, 0x66, 0x66, 0x66, 0x66,
        0x67, 0x9b, 0xcc, 0xcd, 0xee, 0xef, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff
    },
    {
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xfe, 0x98, 0x88, 0x8b, 0xee,
        0xff, 0xe9, 0x99, 0x88, 0x88, 0x88, 0x89, 0x9a,
        0xbc, 0xcc, 0xdd, 0xde, 0xef, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff
    },
    {
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xfe, 0xdd, 0xdd, 0xee,
        0xff, 0xff, 0xed, 0xdd, 0xdd, 0xdd, 0xdd, 0xdd,
        0xdd, 0xdd, 0xde, 0xef, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff
    },
    {
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xfe, 0xdd, 0xdd, 0xef,
        0xff, 0xff, 0xed, 0xdd, 0xdd, 0xdd, 0xdd, 0xdd,
        0xde, 0xee, 0xef, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff
    },
    {
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xee, 0xee, 0xff,
        0xff, 0xff, 0xee, 0xee, 0xee, 0xee, 0xee, 0xee,
        0xee, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff
    },
    {
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff,
        0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff, 0xff
    }
};

//*****************************************************************************
//
// The error routine that is called if the driver library encounters an error.
//
//*****************************************************************************
#ifdef DEBUG
void
__error__(char *pcFilename, unsigned long ulLine)
{
}
#endif

//*****************************************************************************
//
// Display scrolling text plus graphics on the OLED display.
//
//*****************************************************************************
int
main(void)
{
    unsigned long ulRow, ulCol;
    volatile int iDelay;
    static unsigned char pucBuf[64];
    static char pucHello[] =
    {
        "                      "
        "See How Far Your Dollar Can Go!"
        "                      "
    };

    //
    // Set the clocking to run directly from the crystal.
    //
    SysCtlClockSet(SYSCTL_SYSDIV_1 | SYSCTL_USE_OSC | SYSCTL_OSC_MAIN |
                   SYSCTL_XTAL_8MHZ);

    //
    // Initialize the OLED display.
    //
    OSRAM128x64x4Init(1000000);

    //
    // Display the BMP Image.
    // The image is a 55 row by 128 column 4-bit gray scale image
    // in BMP format.
    //
    for(ulRow = 0; ulRow < 55; ulRow++)
    {
        for(ulCol = 0; ulCol < 64; ulCol++)
        {
            //
            // Invert the the pixel values.
            //
            pucBuf[ulCol] = ~g_pucLogo[ulRow][ulCol];
        }

        //
        // Display in reverse row order.
        //
        OSRAM128x64x4ImageDraw(pucBuf, 0, (64 - ulRow), 128, 1);
    }

    //
    // Simple scrolling text display
    //
    ulCol = 0;
    while(1)
    {
        //
        // Display the text.
        //
        OSRAM128x64x4StringDraw(&pucHello[ulCol++], 0, 0, 11);

        //
        // Delay for a bit.
        //
        for(iDelay = 0; iDelay < 100000; iDelay++)
        {
        }

        //
        // Wrap the index back to the beginning of the string.
        //
        if(ulCol > 53)
        {
            ulCol = 0;
        }
    }
}
